@@ -97,6 +97,11 @@ sub handler {
 
   # get user password entry
   my $pwd_table = Net::NISPlus::Table->new($passwd_table);
+  unless ($pwd_table){
+    $r->note_basic_auth_failure;
+    $r->log_reason("$self: cannot get nis+ passwd table", $r->uri);
+    return AUTH_REQUIRED;
+  }
   my $pwd = "";
   my $group = "";
   foreach ($pwd_table->list()){
@@ -156,6 +161,11 @@ sub authz {
     # concept of nt domain groups in Authen::Smb
     elsif($require eq "group") {
       my $group_table = Net::NISPlus::Table->new($group_table);
+      unless ($group_table){
+        $r->note_basic_auth_failure;
+        $r->log_reason("$self: cannot get nis+ group table", $r->uri);
+        return AUTH_REQUIRED;
+      }
       my %groups_to_gids;
       foreach ($group_table->list()){$groups_to_gids{@{$_}[0]} = @{$_}[2]}
       for my $group (@rest) {
